@@ -6,6 +6,11 @@ class IncidentHistory(models.Model, MojoModel):
         ordering = ['-created']
 
     class RestMeta:
+        VIEW_PERMS = ["manage_incidents", "view_incidents"]
+        SAVE_PERMS = ["manage_incidents"]
+        DELETE_PERMS = ["manage_incidents"]
+        CAN_DELETE = False  # History should not be deletable
+
         GRAPHS = {
             "default": {
                 "extra": [
